# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Archive-Tar
Version:	2.38
Release:	1.%{__distinit}%{__distvers}
Summary:	A module for Perl manipulation of .tar files
License:	GPL+ or Artistic
URL:		https://metacpan.org/release/Archive-Tar
Source0:	https://cpan.metacpan.org/modules/by-module/Archive/Archive-Tar-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(File::Copy)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Config)
BuildRequires:	perl(constant)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Spec::Unix)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(IO::Zlib) >= 1.01
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Script Runtime
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(Getopt::Long)
BuildRequires:	perl(Getopt::Std)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(Pod::Usage)
# Test Suite
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(FindBin)
BuildRequires:	perl(IPC::Cmd)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Pod) >= 0.95
# Dependencies
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

# Optional Functionality

# For gzip tarball support
BuildRequires:	perl(Compress::Zlib) >= 2.015
Requires:	perl(Compress::Zlib) >= 2.015

# For bzip tarball support
BuildRequires:	perl(IO::Compress::Bzip2) >= 2.015
BuildRequires:	perl(IO::Uncompress::Bunzip2) >= 2.015
Requires:	perl(IO::Compress::Bzip2) >= 2.015
Requires:	perl(IO::Uncompress::Bunzip2) >= 2.015

# For xz tarball support
BuildRequires:	perl(IO::Compress::Xz)
BuildRequires:	perl(IO::Uncompress::UnXz)
Requires:	perl(IO::Compress::Xz)
Requires:	perl(IO::Uncompress::UnXz)

# For creation of stringified archives
BuildRequires:	perl(IO::String)
Requires:	perl(IO::String)

# For ptardiff
BuildRequires:	perl(Text::Diff)
Requires:	perl(Text::Diff)

%description
Archive::Tar provides an object oriented mechanism for handling tar
files. It provides class methods for quick and easy files handling
while also allowing for the creation of tar file objects for custom
manipulation. Archive::Tar also supports compressed or gzipped tar
files.

%prep
%setup -q -n Archive-Tar-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc CHANGES README
%{_bindir}/ptar
%{_bindir}/ptardiff
%{_bindir}/ptargrep
%{perl_vendorlib}/Archive/
%{_mandir}/man1/ptar.1*
%{_mandir}/man1/ptardiff.1*
%{_mandir}/man1/ptargrep.1*
%{_mandir}/man3/Archive::Tar.3*
%{_mandir}/man3/Archive::Tar::File.3*

%changelog
* Thu Jun 25 2020 Paul Howarth <paul@city-fan.org> - 2.38-1
- Update to 2.36
  - Avoid indirect calls
  - Add use warnings to bin/ptar*

* Sun Feb  2 2020 Paul Howarth <paul@city-fan.org> - 2.36-1
- Update to 2.36
  - Add xz test files to MANIFEST

* Sun Feb  2 2020 Paul Howarth <paul@city-fan.org> - 2.34-1
- Update to 2.34
  - Add xz support
  - Use 4 digit year in Time::Local call
- Include test files missing from upstream distribution
  https://github.com/jib/archive-tar-new/issues/27

* Thu Sep 13 2018 Paul Howarth <paul@city-fan.org> - 2.32-1
- Update to 2.32
  - Fix absolute path handling on VMS

* Wed Jun 20 2018 Paul Howarth <paul@city-fan.org> - 2.30-1
- Update to 2.30
  - Skip white_space test on MSWin32 as Windows will report that both files
    exist, which is obviously a 'feature'

* Fri Jun  8 2018 Paul Howarth <paul@city-fan.org> - 2.28-1
- Update to 2.28
  - Address directory traversal vulnerability (CPAN RT#125523, CVE-2018-12015)
  - Fix creating file with trailing whitespace in filename (CPAN RT#103279)
  - Allow archiving with absolute pathnames (CPAN RT#97748)
  - Small POD fix
  - Speed up extract when archive contains lots of files
- Switch upstream from search.cpan.org to metacpan.org
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Sun May 14 2017 Paul Howarth <paul@city-fan.org> - 2.26-1
- Update to 2.26
  - '0' is a valid name for an archive; change 'iter' to check definedness
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop EL-5-specific epoch

* Sun Dec 18 2016 Paul Howarth <paul@city-fan.org> - 2.24-1
- Update to 2.24
  - Add missing strict/warnings pragma to Constants.pm
  - Handle tarballs compressed with pbzip2 (CPAN RT#119262)

* Thu Dec 15 2016 Paul Howarth <paul@city-fan.org> - 2.20-1
- Update to 2.20
  - Check for gzip/bzip2 before round tripping gz/bz2 files in tests

* Mon Nov  7 2016 Paul Howarth <paul@city-fan.org> - 2.18-1
- Update to 2.18
  - Capture also the STDERR when checking tar exe

* Wed Nov  2 2016 Paul Howarth <paul@city-fan.org> - 2.16-1
- Update to 2.16
  - Make roundtrip tar exe finding robust for crappy tars

* Thu Oct 20 2016 Paul Howarth <paul@city-fan.org> - 2.14-1
- Update to 2.14
  - Fix roundtrip test when tar executable is absent

* Sun Oct 16 2016 Paul Howarth <paul@city-fan.org> - 2.12-1
- Update to 2.12
  - Fix pod in bin/ptar
  - Distinguish between archives with/without directory entries

* Wed Jul 27 2016 Paul Howarth <paul@city-fan.org> - 2.10-1
- Update to 2.10
  - CVE-2016-1238: avoid loading optional modules from default .

* Thu May 12 2016 Paul Howarth <paul@city-fan.org> - 2.08-1
- Update to 2.08
  - Add the roundtrip test to MANIFEST
- BR: perl-generators where possible

* Mon Apr 25 2016 Paul Howarth <paul@city-fan.org> - 2.06-1
- Update to 2.06
  - Changed some of the "A"s in the UNPACK constant to "a" to allow trailing
    whitespaces in an archived filename
  - Roundtrip tests
- Classify buildreqs by usage
- Simplify find command using -delete

* Mon Dec 15 2014 Paul Howarth <paul@city-fan.org> - 2.04-1
- Update to 2.04
  - Enable ptargrep.t to work on VMS (CPAN RT#100903)

* Mon Sep 22 2014 Paul Howarth <paul@city-fan.org> - 2.02-1
- Update to 2.02
  - Tests should now be able to be run in parallel

* Tue Sep  2 2014 Paul Howarth <paul@city-fan.org> - 2.00-2
- Perl 5.20 rebuild

* Mon Jun 16 2014 Paul Howarth <paul@city-fan.org> - 2.00-1
- Update to 2.00
  - ptardiff and ptargrep should use prefix if defined
  - Fix ptargrep for problems on MSWin32
- Drop %%defattr, redundant since rpm 4.4

* Thu Oct 24 2013 Paul Howarth <paul@city-fan.org> - 1.96-1
- Update to 1.96
  - Integrate Package::Constants into Constant module and remove requirement on
    it

* Thu Oct 24 2013 Paul Howarth <paul@city-fan.org> - 1.94-1
- Update to 1.94
  - Install into site by default if perl ≥ 5.012
  - Fix symlinks resolution on MSWin32 (CPAN RT#78030)

* Fri Jul 19 2013 Paul Howarth <paul@city-fan.org> - 1.92-2
- Perl 5.18 rebuild

* Tue Jun 18 2013 Paul Howarth <paul@city-fan.org> - 1.92-1
- Update to 1.92
  - Typo fixes

* Thu Sep  6 2012 Paul Howarth <paul@city-fan.org> - 1.90-1
- Update to 1.90
  - Documentation fixes

* Tue Jul  3 2012 Paul Howarth <paul@city-fan.org> - 1.88-3
- BR: perl(Cwd), perl(Exporter), perl(File::Path), perl(File::Spec::Unix),
  perl(IO::File) and perl(lib)

* Fri Jun  1 2012 Paul Howarth <paul@city-fan.org> - 1.88-1
- Update to 1.88
  - Fixed issue with chown not working on symlinks

* Mon May 28 2012 Paul Howarth <paul@city-fan.org> - 1.86-2
- Bump epoch to 1 for EL-5 only to match upstream package

* Thu May 24 2012 Paul Howarth <paul@city-fan.org> - 1.86-1
- Update to 1.86
  - Don't use tell on IO::Zlib handles (CPAN RT#64339)
- BR: perl(Data::Dumper)

* Sat Mar  3 2012 Paul Howarth <paul@city-fan.org> - 1.84-1
- Update to 1.84
  - ptar now supports -T option (CPAN RT#75473)
  - ptar now supports dashless options (CPAN RT#75475)
  - Auto-encode filenames marked as UTF-8 (CPAN RT#75474)
- Don't need to remove empty directories from buildroot
- Drop support for distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Mon Nov 21 2011 Paul Howarth <paul@city-fan.org> - 1.82-1
- Update to 1.82
  - Adjustments to handle files >8gb (>0777777777777 octal)
  - Feature to return the MD5SUM of files in the archive

* Thu Oct 13 2011 Paul Howarth <paul@city-fan.org> - 1.80-1
- Update to 1.80
  - Add file chown() method (CPAN RT#71221)
- BR: perl(Carp)

* Fri Sep  9 2011 Paul Howarth <paul@city-fan.org> - 1.78-1
- Update to 1.78
  - Add chown() method (CPAN RT#70623)
  - Use "||" rather than "or" (Perl RT#78708)

* Tue Jun 21 2011 Paul Howarth <paul@city-fan.org> - 1.76-2
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Jan 10 2011 Paul Howarth <paul@city-fan.org> - 1.76-1
- Update to 1.76 (upstream blead fixes)

* Sun Dec 19 2010 Paul Howarth <paul@city-fan.org> - 1.74-1
- Update to 1.74 (skip extracting pax extended headers - CPAN RT#64038)

* Fri Nov 19 2010 Paul Howarth <paul@city-fan.org> - 1.72-1
- Update to 1.72 (update docs for ptargrep)

* Tue Nov 16 2010 Paul Howarth <paul@city-fan.org> - 1.70-1
- Update to 1.70 (add ptargrep utility)

* Wed Aug 18 2010 Paul Howarth <paul@city-fan.org> - 1.68-1
- Update to 1.68 (check whether long files can be created or not in
  02_methods.t, hopefully resolving CPAN RT#57312 and CPAN RT#56163)

* Tue Jul 27 2010 Paul Howarth <paul@city-fan.org> - 1.66-1
- Update to 1.66
  - Fix Makefile.PL to produce better META.yml (CPAN RT#59699)
  - Add option -C to ptar (CPAN RT#59700)
- Add dependency on perl(IO::String) for creation of stringified archives
- Explicitly add buildreqs that were only pulled in implicitly

* Fri Jul  9 2010 Paul Howarth <paul@city-fan.org> - 1.64-1
- Update to 1.64
  - Remove the PERL_CORE specific chdir from all the tests
  - Improvements to file skipping (CPAN RT#58916)
  - Don't assume all filenames are IO::Handles (CPAN RT#59150)

* Tue Jun 29 2010 Paul Howarth <paul@city-fan.org> - 1.62-1
- Update to 1.62 (partly address problem with exit status of
  Archive::Tar->extract_archive() [#606813, CPAN RT#58636])

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 1.60-3
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> - 1.60-2
- Fix dist tag for RHEL-6 Beta

* Fri Apr 23 2010 Paul Howarth <paul@city-fan.org> - 1.60-1
- Update to 1.60 (fix for CPAN RT#54850, making write() and create_archive()
  close only handles they opened)

* Fri Feb 19 2010 Paul Howarth <paul@city-fan.org> - 1.58-1
- Update to 1.58 ($@ not cleaned up after eval - CPAN RT#54714)
- Revert to %%{__chmod} for permissions fixing for old distro compatibility

* Wed Feb  3 2010 Paul Howarth <paul@city-fan.org> - 1.56-1
- Update to 1.56 (compatibility hack for busybox - CPAN RT#50471)
- Use %%{_fixperms} macro rather than our own %%{__chmod} incantation
- Dist tag for Rawhide no longer needs special-casing

* Thu Sep 10 2009 Paul Howarth <paul@city-fan.org> - 1.54-1
- Update to 1.54 (fix global errors - CPAN RT#48879)
- New upstream maintainer -> new URL

* Mon Jun 15 2009 Paul Howarth <paul@city-fan.org> - 1.52-1
- Update to 1.52 (support for --no-same-permissions style behavior)

* Tue May  5 2009 Paul Howarth <paul@city-fan.org> - 1.48-1
- Import from Fedora
- Update to 1.48
- Buildreq perl(IO::Zlib) >= 1.01
- Buildreq perl(Package::Constants)
- Buildreq+req perl(Compress::Zlib) >= 2.015
- Buildreq+req perl(IO::Compress::Bzip2) >= 2.015
- Buildreq+req perl(Text::Diff)

* Thu Aug 23 2007 Robin Norwood <rnorwood@redhat.com> - 1.34-1
- Upgrade to latest upstream version: 1.34
- Fix license tag
- Fix BuildRequires for ExtUtils::MakeMaker and Test::Pod

* Mon Jun 04 2007 Robin Norwood <rnorwood@redhat.com> - 1.32-1
- Upgrade to latest upstream version: 1.32

* Mon Mar 05 2007 Robin Norwood <rnorwood@redhat.com> - 1.30-4
- Fix changelog

* Mon Feb 19 2007 Robin Norwood <rnorwood@redhat.com> - 1.30-3
- Incorporate specfile improvements from Jose Oliveira

* Fri Feb 16 2007 Robin Norwood <rnorwood@redhat.com> - 1.30-2
- Resolves: rhbz#226239 - Remove tabs from spec file for package review

* Tue Sep 19 2006 Robin Norwood <rnorwood@redhat.com> - 1.30-1
- Bump to 1.30

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 1.29-1.1
- Rebuild

* Wed Mar 08 2006 Jason Vas Dias <jvdias@redhat.com> - 1.29-1
- Upgrade to upstream version 1.29

* Fri Feb 03 2006 Jason Vas Dias <jvdias@redhat.com> - 1.28-1
- Upgrade to upstream version 1.28
- Rebuild for perl-5.8.8

* Fri Dec 16 2005 Jesse Keating <jkeating@redhat.com> - 1.26-1.1
- Rebuilt for new gcc

* Sun Nov 06 2005 Florian La Roche <laroche@redhat.com> - 1.26-1
- 1.26

* Mon Apr 25 2005 Warren Togami <wtogami@redhat.com> - 1.23-4
- Remove beehive workaround

* Sun Apr 03 2005 Jose Pedro Oliveira <jpo@di.uminho.pt> - 1.23-1
- Update to 1.23
- Bring up to date with current Fedora.Extras perl spec template

* Wed Sep 22 2004 Chip Turner <cturner@redhat.com> - 1.08-3
- Rebuild

* Fri Feb 13 2004 Chip Turner <cturner@redhat.com> - 1.08-1
- Update to upstream 1.08

* Wed Jan 22 2003 Tim Powers <timp@redhat.com>
- Rebuilt

* Tue Aug  6 2002 Chip Turner <cturner@redhat.com>
- Automated release bump and build

* Fri Feb 08 2002 cturner@redhat.com
- Specfile autogenerated
